<?php
namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\CardsService;
use FM\Traits\TResponse;

class CardsController extends FMCrud{
    
    use TResponse;
    
    protected $dataSourceName = 'fcm_checklistagend';
    protected $CardsService;
   
    public function __construct($crudService, $environment, CardsService $CardsService) {
        parent::__construct($crudService, $environment);
        $this->CardsService = $CardsService;
    }

    public function getTipoLocal(DTO\Request $request, DTO\Response $response) {
        $variavel = $this->CardsService->buscandoTipoLocal();
        $dtsVal = new DataSet('tipoLocal', $variavel);
        $response->addDataSet($dtsVal);
    }

    public function getLocal(DTO\Request $request, DTO\Response $response) {
        $variavel = $this->CardsService->buscandoLocal();
        $dtsVal = new DataSet('local', $variavel);
        $response->addDataSet($dtsVal);
    }

    public function itensChecklist(DTO\Request $request, DTO\Response $response) {
        $response->addDataSet(new DataSet('itensChecklist', $this->CardsService->getItensChecklist()));
    }

    public function getCriterios(DTO\Request $request, DTO\Response $response) {
        $response->addDataSet(new DataSet('criterio', $this->CardsService->getCriterios()));
    }

    public function getChecklist(DTO\Request $request, DTO\Response $response) {
        $variavel = $this->CardsService->buscandoChecklist();
        $dtsVal = new DataSet('checklist', $variavel);
        $response->addDataSet($dtsVal);
    }

    public function getItensChecklist(DTO\Request $request, DTO\Response $response) {
        $param = $request->getParameters();
        $variavel = $this->CardsService->buscandoItensChecklist($param);
        $dtsVal = new DataSet('tipoTarefa', $variavel);
        $response->addDataSet($dtsVal);
    }

    public function getFuncionario(DTO\Request $request, DTO\Response $response) {
        $variavel = $this->CardsService->buscandoFuncionario();
        $dtsVal = new DataSet('funcionario', $variavel);
        $response->addDataSet($dtsVal);
    }
    
    public function getSupervisor(DTO\Request $request, DTO\Response $response) {
        $variavel = $this->CardsService->buscandoSupervisor();
        $dtsVal = new DataSet('funcionario', $variavel);
        $response->addDataSet($dtsVal);
    }

    public function getFuncionarioDataSource(DTO\Request $request, DTO\Response $response) {
        try {
            $data = $this->CardsService->buscandoFuncionarioDataSource();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function getSupervisorDataSource(DTO\Request $request, DTO\Response $response) {
        try {
            $data = $this->CardsService->buscandoSupervisorDataSource();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getCriterioTarefa(DTO\Request $request, DTO\Response $response) {
        $param = $request->getParameters();
        $variavel = $this->CardsService->buscandoCriterioTarefa($param);
        $dtsVal = new DataSet('criterioTarefa', $variavel);
        $response->addDataSet($dtsVal);
    }

    public function getTarefa(DTO\Request $request, DTO\Response $response) {
        $param = $request->getParameters();
        $variavel = $this->CardsService->buscandoTarefa($param);
        $dtsVal = new DataSet('tarefa', $variavel);
        $response->addDataSet($dtsVal);
    }
    
    public function getCriterioAtividade(DTO\Request $request, DTO\Response $response) {
        $param = $request->getParameters();
        $variavel = $this->CardsService->buscandoCriterioAtividade($param);
        $dtsVal = new DataSet('criterioTarefa', $variavel);
        $response->addDataSet($dtsVal);
    }
    
    // ----- APAGAR
    /* public function getCard(DTO\Request $request, DTO\Response $response) {
        // debugApi([$this->environment->getNrOrg(),$this->environment->getCdOperador()]);
        $response->addDataSet(new DataSet('cards', $this->CardsService->buscandoCard($request->getParameters())));
    } */

    public function getTarefas(Request $request, Response $response) {
        try {
                $data = $this->CardsService->getTarefas($request->getParameters());
                $this->sendResponse($data, 200);
            } catch (Exception $ex) {
                $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            }
    }

    public function getLocaisDasTarefas(Request $request, Response $response) {
        try {
                $data = $this->CardsService->getLocaisDasTarefas();
                $this->sendResponse($data, 200);
            } catch (Exception $ex) {
                $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            }
    }

    public function getFuncionariosDasTarefas(Request $request, Response $response) {
        try {
                $data = $this->CardsService->getFuncionariosDasTarefas();
                $this->sendResponse($data, 200);
            } catch (Exception $ex) {
                $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            }
    }
    
    public function getChecklistDasTarefas(Request $request, Response $response) {
        try {
                $data = $this->CardsService->getChecklistDasTarefas();
                $this->sendResponse($data, 200);
            } catch (Exception $ex) {
                $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            }
    }
    
    public function getTipoLocalDasTarefas(Request $request, Response $response) {
        try {
                $data = $this->CardsService->getTipoLocalDasTarefas();
                $this->sendResponse($data, 200);
            } catch (Exception $ex) {
                $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            }
    }
    
    public function insertNovaTarefa(DTO\Request $request, DTO\Response $response) {

        try {
            $data = $this->CardsService->insertNovaTarefa($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deletarTarefas(DTO\Request $request, DTO\Response $response) {
        try {
            $data = $this->CardsService->deletarTarefas($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function updateTarefa(DTO\Request $request, DTO\Response $response) {
        $response->addDataSet(new DataSet('retorno', $this->CardsService->updateTarefa($request->getParameters())));
    }
    
    public function recriarTarefasRecorrente(Request $request, Response $response){
        try {
            $data = $this->CardsService->playTarefasRecorrente($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
?>