<?php

namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\ChecklistService;
use FM\Traits\TResponse;

class ChecklistController extends FMCrud{
    
    use TResponse;
    
    protected $ChecklistService;
   
    public function __construct($crudService, $environment, ChecklistService $ChecklistService) {
        parent::__construct($crudService, $environment);
        $this->ChecklistService = $ChecklistService;
    }

    public function getChecklist(DTO\Request $request, DTO\Response $response){
        $response->addDataSet(new DataSet("checklist", $this->ChecklistService->getChecklist()));
    }

    public function getChecklistDatasource(DTO\Request $request, DTO\Response $response){
        try {
            $data = $this->ChecklistService->getChecklistDatasource();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSpecificChecklist(DTO\Request $request, DTO\Response $response){
        $params = $request->getParameters();
        $var = $this->ChecklistService->getSpecificChecklist($params);
        $dtsVal = new DataSet("checklist", $var);
        $response->addDataSet($dtsVal);
    }
    
    public function listChecklist(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();
        $checklist = $this->ChecklistService->listChecklist($params);
        $dtsVal = new DataSet('Checklists', $checklist);
        $response->addDataSet($dtsVal);
    }
}

?>